---
title: <span class="badge builder"></span> USAQuery
---
# <span class="badge builder"></span> USAQuery

## Constructor

```python
USAQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.USAQuery
```

### <span class="badge object-method"></span> fields

```python
def fields(fields: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: str) -> typing.Self
```

### <span class="badge object-method"></span> period

```python
def period(period: str) -> typing.Self
```

### <span class="badge object-method"></span> states

```python
def states(states: list[str]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [USAQuery](./object-USAQuery.md)
